package Acme::MetaSyntactic::legoharrypotter;
{
  $Acme::MetaSyntactic::legoharrypotter::VERSION = '0.02';
}

#ABSTRACT: LEGO Harry Potter theme

use strict;
use warnings;
use Acme::MetaSyntactic::List;
our @ISA = qw( Acme::MetaSyntactic::List );
__PACKAGE__->init();

q[You-Know-Who];




=pod

=head1 NAME

Acme::MetaSyntactic::legoharrypotter - LEGO Harry Potter theme

=head1 VERSION

version 0.02

=head1 DESCRIPTION

Characters from the LEGO Harry Potter games years 1-4 and 5-7 as gleaned from
the L<http://www.gamefaqs.com/> walkthroughs.

I<Expelliarmus!>

=head1 SEE ALSO

L<Acme::MetaSyntactic>, L<Acme::MetaSyntactic::List>.

=head1 AUTHOR

Chris Williams

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Chris Williams.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut


__DATA__
# names
aberforth_dumbledore
albert_runcorn
aleeto_carrow
alicia_spinnet
amos_diggory
amycus_carrow
angelina_johnson
anthony_goldstein
antoin_dolohov
argus_filch
arthur_weasley
barty_crouch_junior
barty_crouch_senior
bassist
bellatrix_lestrange
blaise_zabini
bogrod
cedric_diggory
charity_burbage
charlie_weasley
cho_chang
colin_creevey
cormac_mclaggen
cornelius_fudge
dean_thomas
death_eater
dedalus_diggle
dirk_cresswell
dobby
doris_crockford
draco_malfoy
dragomir_despard
dragon_handler
drummer
dudley_dursley
dudleys_gang_member
durmstrang_student
elphias_doge
emmeline_vance
ernie_macmillan
ernie_prang
fang
fat_lady
fenrir_greyback
filch
fleur_delacour
fred_weasley
gabrielle_delacour
george_weasley
gilderoy_lockhart
ginny_weasley
gregorovitch
gregory_goyle
griphook
gryffindor_boy
gryffindor_girl
guitarist
hagrid
hannah_abbott
harry_potter
hermione_granger
hestia_jones
hufflepuff_boy
hufflepuff_girl
hufflepuff_prefect
igor_karkaroff
james_potter
justin_finch_fletchley
katie_bell
kingsley_shacklebolt
kreacher
krum_shark
lavender_brown
lee_jordan
lily_potter
lord_voldemort
lucius_malfoy
luna_lovegood
macnair
madame_malkin
madam_hooch
madam_irma_pince
madam_malkin
madam_pince
madam_pomfrey
madam_rosmerta
mad_eye_moody
mafalda_hopkirk
marcus_belby
marcus_flint
marietta_edgecombe
mary_cattermole
michael_corner
milk_man
millicent_bulstrode
ministry_guard
moaning_myrtle
molly_weasley
mr_mason
mr_ollivander
mrs_black
mrs_cole
mrs_figg
mrs_mason
muggle_orphan
mundungus_fletcher
narcissas_malfoy
nearly_headless_nick
neville_longbottom
nymphdora_tonks
olver_wood
padma_patil
parvati_patil
penelope_clearwater
percy_weasley
peter_pettigrew
petunia_dursley
pius_thicknesse
professor_binns
professor_dumbledore
professor_flitwick
professor_grubbly_plank
professor_lupin
professor_mcgonagall
professor_mcgonnagal
professor_quirrell
professor_sinistra
professor_slughorn
professor_snape
professor_sprout
professor_trelawney
professor_trelawny
professor_umbridge
professor_vector
ravenclaw_boy
ravenclaw_girl
ravenclaw_prefect
reg_cattermole
regulus_black
remus_lupin
rita_skeeter
ron_weasley
rufus_scrimgeour
scabior
seamus_finnigan
shifty_wizard
sirius_black
skeleton
slytherin_boy
slytherin_girl
slytherin_prefect
slytherin_twin_1
slytherin_twin_2
snatcher
stan_shunpike
station_guard
susan_bones
the_bloody_baron
the_fat_friar
the_grey_lady
thorfin_rowle
tom_riddle
tom_the_innkeeper
trolley_witch
vernon_dursley
viktor_krum
vincent_crabbe
vocalist
wormtail
xenophilius_lovegood
yaxley
zacharias_smith
